import argparse
from bukka.logistics.project import Project
from bukka.utils import bukka_logger

logger = bukka_logger.BukkaLogger(__name__)

def main(name, dataset):
    logger.info('Creating Bukka project!', format_level='h1')
    
    proj = Project(
        name,
        dataset_path=dataset
    )

    proj.run()

if __name__ == '__main__':
    parser = argparse.ArgumentParser()

    parser.add_argument('--name', '-n', type=str, required=True)
    parser.add_argument('--dataset', '-d', type=str, required=False, default=None)

    args = parser.parse_args()

    main(
        name=args.name,
        dataset=args.dataset
    )


import venv
import os
import subprocess
from bukka.logistics.files.file_manager import FileManager
from bukka.utils.reference import requirements

class EnvironmentBuilder:
    def __init__(self, file_manager: FileManager):
        self.file_manager = file_manager


    def build_environment(self):
        self._build_venv()
        self._install_packages()

    def _build_venv(self):
        venv_client = venv.EnvBuilder(
            with_pip=True
        )

        venv_client.create(
            env_dir=self.file_manager.virtual_env
        )

    def _install_packages(self):
        with open(self.file_manager.requirements_path, 'w') as f:
            f.write(requirements.strip())

        cmd_list = [
            str(self.file_manager.python_path),
            '-m',
            'pip',
            'install',
            '-r',
            str(self.file_manager.requirements_path)
        ]

        subprocess.run(cmd_list)



from bukka.logistics.files.file_manager import FileManager
from bukka.logistics.environment.environment import EnvironmentBuilder

class Project:
    def __init__(self, name, dataset_path):
        self.name = name
        self.dataset_path = dataset_path

    def run(self):
        self._build_skeleton()
        self._setup_environment()

    def _build_skeleton(self):
        self.file_manager = FileManager(
            project_path=self.name,
            orig_dataset=self.dataset_path
        )

        self.file_manager.build_skeleton()

    def _setup_environment(self):
        self.environ_manager = EnvironmentBuilder(
            file_manager=self.file_manager
        )

        self.environ_manager.build_environment()